Index: /issm/trunk/src/c/objects/Elements/Penta.cpp
===================================================================
--- /issm/trunk/src/c/objects/Elements/Penta.cpp	(revision 3816)
+++ /issm/trunk/src/c/objects/Elements/Penta.cpp	(revision 3817)
@@ -45,5 +45,5 @@
 	int penta_matice_id;
 	int penta_matpar_id;
-	int penta_element_ids[2];
+	int penta_elements_ids[2];
 	double nodeinputs[6];
 	bool collapse;
@@ -58,11 +58,11 @@
 	penta_matice_id=index+1; //refers to the corresponding ice material object
 	penta_matpar_id=iomodel->numberofelements+1; //refers to the constant material parameters object
-	penta_elements_ids[0]=(int)*(iomodel->upperelements[index]);
-	penta_elements_ids[1]=(int)*(iomodel->lowerelements[index]);
+	penta_elements_ids[0]=(int)(iomodel->upperelements[index]);
+	penta_elements_ids[1]=(int)(iomodel->lowerelements[index]);
 
 	this->InitHookNodes(penta_node_ids); this->nodes=NULL;
 	this->InitHookMatice(penta_matice_id);this->matice=NULL;
 	this->InitHookMatpar(penta_matpar_id);this->matpar=NULL;
-	this->InitHookNeighboors(penta_element_ids);this->neighboors=NULL;
+	this->InitHookNeighboors(penta_elements_ids);this->neighboors=NULL;
 
 	//intialize inputs, and add as many inputs per element as requested: 
@@ -208,5 +208,5 @@
 	penta->matice=(Matice*)penta->hmatice.delivers();
 	penta->matpar=(Matpar*)penta->hmatpar.delivers();
-	penta->neighboors=(Penta**)penta->hneighboors.deliverp();
+	penta->neighboors=(Penta*)penta->hneighboors.deliverp();
 
 	return penta;
@@ -229,5 +229,5 @@
 	this->matice=(Matice*)this->hmatice.delivers();
 	this->matpar=(Matpar*)this->hmatpar.delivers();
-	this->neighboors=(Penta**)this->hneighboors.deliverp();
+	this->neighboors=(Penta*)this->hneighboors.deliverp();
 
 	/*point parameters to real dataset: */
@@ -286,5 +286,5 @@
 	matice->DeepEcho();
 	matpar->DeepEcho();
-	printf("   neigboor ids: %i-%i\n",neigboors[0]->Id(),neigboors[1]->Id());
+	printf("   neighbor ids: %i-%i\n",neighbors[0]->Id(),neighbors[1]->Id());
 	printf("   parameters\n");
 	parameters->DeepEcho();
Index: /issm/trunk/src/c/objects/Elements/Penta.h
===================================================================
--- /issm/trunk/src/c/objects/Elements/Penta.h	(revision 3816)
+++ /issm/trunk/src/c/objects/Elements/Penta.h	(revision 3817)
@@ -32,5 +32,5 @@
 		Matice      *matice;       // 1 material ice
 		Matpar      *matpar;       // 1 material parameter
-		Penta       *neighboors;   // 2 neighboors: first one under, second one above
+		Penta       *neighbors;   // 2 neighbors: first one under, second one above
 
 		Parameters  *parameters;   //pointer to solution parameters
